==> jugglingdb-2.0.0-rc2.tgz: package/test/datatype.test.js <==
// This test written in mocha+should.js
var should = require('./init.js');

var db, Model;

describe('datatypes', function() {

    before(function(done){
        db = getSchema();
        Model = db.define('Model', {
            str: String,
            date: Date,
            num: Number,
            bool: Boolean,
            list: {type: []},
        });
        db.automigrate(function() {
            Model.destroyAll(done);
        });
    });

    it('should keep types when get read data from db', function(done) {
        var d = new Date, id;

        Model.create({
            str: 'hello', date: d, num: '3', bool: 1, list: ['test']
        }, function(err, m) {
            should.not.exist(err);
            should.exist(m && m.id);
            m.str.should.be.a.String;
            m.num.should.be.a.Number;
            m.bool.should.be.a.Boolean;
            id = m.id;
            testFind(testAll);
        });

        function testFind(next) {
            Model.find(id, function(err, m) {
                should.not.exist(err);
                should.exist(m);
                m.str.should.be.a.String;
                m.num.should.be.a.Number;
                m.bool.should.be.a.Boolean;
                m.date.should.be.an.instanceOf(Date);
                m.date.toString().should.equal(d.toString(), 'Time must match');
                next();
            });
        }

        function testAll() {
            Model.findOne(function(err, m) {
                should.not.exist(err);
                should.exist(m);
                m.str.should.be.a.String;
                m.num.should.be.a.Number;
                m.bool.should.be.a.Boolean;
                m.date.should.be.an.instanceOf(Date);
                m.date.toString().should.equal(d.toString(), 'Time must match');
                done();
            });
        }

    });

    it('should convert "false" to false for boolean', function() {
        var m = new Model({bool: 'false'});
        m.bool.should.equal(false);
    });

});

==> jugglingdb-2.0.1.tgz: package/test/datatype.test.js <==
// This test written in mocha+should.js
const should = require('./init.js');

let db, Model;

describe('datatypes', function() {

    before(function(done) {
        db = getSchema();
        Model = db.define('Model', {
            str: String,
            date: Date,
            num: Number,
            bool: Boolean
        });
        db.automigrate(function() {
            Model.destroyAll(done);
        });
    });

    it('should keep types when get read data from db', function() {
        let d = new Date, id;

        d.setMilliseconds(0);

        return Model.create({
            str: 'hello',
            date: d,
            num: '3',
            bool: 1
        })
            .then(function(m) {
                should.exist(m && m.id);
                m.str.should.be.a.String;
                m.num.should.be.a.Number;
                m.bool.should.be.a.Boolean;
                id = m.id;
                return Model.find(id);
            })
            .then(function(m) {
                should.exist(m);
                m.str.should.be.a.String;
                m.num.should.be.a.Number;
                m.bool.should.be.a.Boolean;
                m.date.should.be.an.instanceOf(Date);
                m.date.toString().should.equal(d.toString(), 'Time must match');
                return Model.findOne();
            })
            .then(function(m) {
                should.exist(m);
                m.str.should.be.a.String;
                m.num.should.be.a.Number;
                m.bool.should.be.a.Boolean;
                m.date.should.be.an.instanceOf(Date);
                m.date.toString().should.equal(d.toString(), 'Time must match');
            });
    });

    it('should convert "false" to false for boolean', function() {
        const m = new Model({ bool: 'false' });
        m.bool.should.equal(false);
    });

});
